# Copyright 2025 ForgeFlow S.L. (https://www.forgeflow.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from openupgradelib import openupgrade


def assure_website_page_url_is_filled(env):
    openupgrade.logged_query(
        env.cr,
        """
        UPDATE website_page
        SET url = ''
        WHERE url IS NULL
        """,
    )


@openupgrade.migrate()
def migrate(env, version):
    assure_website_page_url_is_filled(env)
    openupgrade.set_xml_ids_noupdate_value(
        env,
        "website",
        [
            "business_conference",
            "header_image_1_default_image",
            "library_image_01",
            "library_image_02",
            "library_image_03",
            "library_image_04",
            "library_image_05",
            "library_image_06",
            "library_image_07",
            "library_image_08",
            "library_image_09",
            "library_image_10",
            "library_image_11",
            "library_image_12",
            "library_image_13",
            "library_image_14",
            "library_image_15",
            "library_image_16",
            "library_image_17",
            "library_image_18",
            "s_background_image_01",
            "s_background_image_02",
            "s_background_image_03",
            "s_background_image_04",
            "s_background_image_05",
            "s_background_image_06",
            "s_background_image_07",
            "s_background_image_08",
            "s_background_image_09",
            "s_banner_default_image",
            "s_blockquote_cover_default_image",
            "s_blockquote_default_image",
            "s_carousel_default_image_1",
            "s_carousel_default_image_2",
            "s_carousel_default_image_3",
            "s_company_team_image_1",
            "s_company_team_image_2",
            "s_company_team_image_3",
            "s_company_team_image_4",
            "s_cover_default_image",
            "s_image_text_default_image",
            "s_masonry_block_default_image_1",
            "s_masonry_block_default_image_2",
            "s_media_list_default_image_1",
            "s_media_list_default_image_2",
            "s_media_list_default_image_3",
            "s_mega_menu_cards_default_image_1",
            "s_mega_menu_cards_default_image_2",
            "s_mega_menu_cards_default_image_3",
            "s_mega_menu_cards_default_image_4",
            "s_mega_menu_cards_default_image_5",
            "s_mega_menu_cards_default_image_6",
            "s_mega_menu_cards_default_image_7",
            "s_mega_menu_cards_default_image_8",
            "s_mega_menu_images_subtitles_default_image_1",
            "s_mega_menu_images_subtitles_default_image_2",
            "s_mega_menu_images_subtitles_default_image_3",
            "s_mega_menu_images_subtitles_default_image_4",
            "s_mega_menu_images_subtitles_default_image_5",
            "s_mega_menu_images_subtitles_default_image_6",
            "s_mega_menu_images_subtitles_default_image_7",
            "s_mega_menu_menu_image_menu_default_image",
            "s_mega_menu_menus_logos_default_image",
            "s_mega_menu_menus_logos_default_logo_1",
            "s_mega_menu_menus_logos_default_logo_2",
            "s_mega_menu_menus_logos_default_logo_3",
            "s_mega_menu_menus_logos_default_logo_4",
            "s_mega_menu_menus_logos_default_logo_5",
            "s_mega_menu_menus_logos_default_logo_6",
            "s_mega_menu_thumbnails_default_image_1",
            "s_mega_menu_thumbnails_default_image_10",
            "s_mega_menu_thumbnails_default_image_11",
            "s_mega_menu_thumbnails_default_image_2",
            "s_mega_menu_thumbnails_default_image_3",
            "s_mega_menu_thumbnails_default_image_4",
            "s_mega_menu_thumbnails_default_image_5",
            "s_mega_menu_thumbnails_default_image_6",
            "s_mega_menu_thumbnails_default_image_7",
            "s_mega_menu_thumbnails_default_image_8",
            "s_mega_menu_thumbnails_default_image_9",
            "s_parallax_default_image",
            "s_picture_default_image",
            "s_popup_default_image",
            "s_product_catalog_default_image",
            "s_product_list_default_image_1",
            "s_product_list_default_image_2",
            "s_product_list_default_image_3",
            "s_product_list_default_image_4",
            "s_product_list_default_image_5",
            "s_product_list_default_image_6",
            "s_quotes_carousel_demo_image_0",
            "s_quotes_carousel_demo_image_1",
            "s_quotes_carousel_demo_image_2",
            "s_quotes_carousel_demo_image_3",
            "s_quotes_carousel_demo_image_4",
            "s_quotes_carousel_demo_image_5",
            "s_reference_default_image_6",
            "s_reference_demo_image_1",
            "s_reference_demo_image_2",
            "s_reference_demo_image_3",
            "s_reference_demo_image_4",
            "s_reference_demo_image_5",
            "s_text_image_default_image",
            "s_three_columns_default_image_1",
            "s_three_columns_default_image_2",
            "s_three_columns_default_image_3",
        ],
        False,
    )
